==> plugin-android-3.0.0-sources.jar: com/zoyi/channel/plugin/android/activity/chat/viewholder/TextMessageHolder.java <==
package com.zoyi.channel.plugin.android.activity.chat.viewholder;

import android.text.method.LinkMovementMethod;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;

import com.zoyi.channel.plugin.android.R;
import com.zoyi.channel.plugin.android.activity.chat.model.ChatMessageItem;
import com.zoyi.channel.plugin.android.activity.chat.type.MessageType;
import com.zoyi.channel.plugin.android.util.UIUtils;
import com.zoyi.channel.plugin.android.view.layout.MaskableFrameLayout;

/**
 * Created by jerry on 2018. 3. 30..
 */

public class TextMessageHolder extends BaseMessageHolder {

  MaskableFrameLayout guestMessageHeadLayout;
  MaskableFrameLayout guestMessageContentLayout;
  TextView guestMessageText;
  View guestMessageTopView;
  View guestMessageContentView;

  View managerMessageHeadTop;
  View managerMessageContextTop;
  TextView managerMessageText;

  public static TextMessageHolder newInstance(ViewGroup parent, MessageType messageType) {
    return new TextMessageHolder(getItemView(parent, messageType), messageType);
  }

  public TextMessageHolder(View itemView, MessageType messageType) {
    super(itemView, messageType);

    switch (messageType) {
      case GUEST_TEXT_MESSAGE:
      case GUEST_IMAGE_MESSAGE:
      case GUEST_FILE_MESSAGE:
      case GUEST_WEB_MESSAGE:
        guestMessageHeadLayout = itemView.findViewById(R.id.ch_layout_guest_message_head);
        guestMessageContentLayout = itemView.findViewById(R.id.ch_layout_guest_message_content);
        guestMessageText = itemView.findViewById(R.id.ch_text_guest_message);
        guestMessageTopView = itemView.findViewById(R.id.ch_view_guest_message_head_top);
        guestMessageContentView = itemView.findViewById(R.id.ch_view_guest_message_content_top);
        break;

      default:
        managerMessageHeadTop = itemView.findViewById(R.id.ch_view_manager_message_head_top);
        managerMessageContextTop = itemView.findViewById(R.id.ch_view_manager_message_context_top);
        managerMessageText = itemView.findViewById(R.id.ch_text_manager_message);
        break;
    }
  }

  public void bind(ChatMessageItem item, boolean isConnectedMessage) {
    super.bind(item.getMessage(), item.getType(), isConnectedMessage);

    switch (item.getType()) {
      case GUEST_TEXT_MESSAGE:
      case GUEST_IMAGE_MESSAGE:
      case GUEST_FILE_MESSAGE:
      case GUEST_WEB_MESSAGE:
        setGuestMessageText(item, isConnectedMessage);
        break;

      default:
        setManagerMessageText(item, isConnectedMessage);
        break;
    }
  }

  private void setGuestMessageText(ChatMessageItem item, boolean isConnectedMessage) {
    if (item.getMessage().getMessage() != null) {
      guestMessageTextLayout.setVisibility(View.VISIBLE);
      guestMessageHeadLayout.setVisibility(UIUtils.getVisible(!isConnectedMessage, true));
      guestMessageContentLayout.setVisibility(UIUtils.getVisible(isConnectedMessage, true));

      guestMessageTopView.setBackgroundColor(item.getMessageBackgroundColor());
      guestMessageContentView.setBackgroundColor(item.getMessageBackgroundColor());
      guestMessageText.setBackgroundColor(item.getMessageBackgroundColor());
      guestMessageText.setTextColor(item.getMessageColor());

      guestMessageText.setText(item.getMessage().getFormattedSpanMessage());
      guestMessageText.setMovementMethod(LinkMovementMethod.getInstance());
    }
  }

  private void setManagerMessageText(ChatMessageItem item, boolean isConnectedMessage) {
    if (item.getMessage().getMessage() != null) {
      managerMessageTextLayout.setVisibility(View.VISIBLE);
      managerMessageHeadTop.setVisibility(UIUtils.getVisible(!isConnectedMessage, true));
      managerMessageContextTop.setVisibility(UIUtils.getVisible(isConnectedMessage, true));

      managerMessageText.setText(item.getMessage().getFormattedSpanMessage());
      managerMessageText.setMovementMethod(LinkMovementMethod.getInstance());
    }
  }
}

==> plugin-android-3.1.0-sources.jar: com/zoyi/channel/plugin/android/activity/chat/viewholder/TextMessageHolder.java <==
package com.zoyi.channel.plugin.android.activity.chat.viewholder;

import android.text.method.LinkMovementMethod;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;

import com.zoyi.channel.plugin.android.R;
import com.zoyi.channel.plugin.android.activity.chat.model.ChatMessageItem;
import com.zoyi.channel.plugin.android.activity.chat.type.MessageType;
import com.zoyi.channel.plugin.android.util.UIUtils;
import com.zoyi.channel.plugin.android.view.layout.CHTextView;
import com.zoyi.channel.plugin.android.view.layout.MaskableFrameLayout;

/**
 * Created by jerry on 2018. 3. 30..
 */

public class TextMessageHolder extends BaseMessageHolder {

  MaskableFrameLayout guestMessageHeadLayout;
  MaskableFrameLayout guestMessageContentLayout;
  CHTextView guestMessageText;
  View guestMessageTopView;
  View guestMessageContentView;

  View managerMessageHeadTop;
  View managerMessageContextTop;
  CHTextView managerMessageText;

  public static TextMessageHolder newInstance(ViewGroup parent, MessageType messageType) {
    return new TextMessageHolder(getItemView(parent, messageType), messageType);
  }

  public TextMessageHolder(View itemView, MessageType messageType) {
    super(itemView, messageType);

    switch (messageType) {
      case GUEST_TEXT_MESSAGE:
      case GUEST_IMAGE_MESSAGE:
      case GUEST_FILE_MESSAGE:
      case GUEST_WEB_MESSAGE:
        guestMessageHeadLayout = itemView.findViewById(R.id.ch_layout_guest_message_head);
        guestMessageContentLayout = itemView.findViewById(R.id.ch_layout_guest_message_content);
        guestMessageText = itemView.findViewById(R.id.ch_text_guest_message);
        guestMessageTopView = itemView.findViewById(R.id.ch_view_guest_message_head_top);
        guestMessageContentView = itemView.findViewById(R.id.ch_view_guest_message_content_top);
        break;

      default:
        managerMessageHeadTop = itemView.findViewById(R.id.ch_view_manager_message_head_top);
        managerMessageContextTop = itemView.findViewById(R.id.ch_view_manager_message_context_top);
        managerMessageText = itemView.findViewById(R.id.ch_text_manager_message);
        break;
    }
  }

  public void bind(ChatMessageItem item, boolean isConnectedMessage) {
    super.bind(item.getMessage(), item.getType(), isConnectedMessage);

    switch (item.getType()) {
      case GUEST_TEXT_MESSAGE:
      case GUEST_IMAGE_MESSAGE:
      case GUEST_FILE_MESSAGE:
      case GUEST_WEB_MESSAGE:
        setGuestMessageText(item, isConnectedMessage);
        break;

      default:
        setManagerMessageText(item, isConnectedMessage);
        break;
    }
  }

  private void setGuestMessageText(ChatMessageItem item, boolean isConnectedMessage) {
    if (item.getMessage().getMessage() != null) {
      guestMessageTextLayout.setVisibility(View.VISIBLE);
      guestMessageHeadLayout.setVisibility(UIUtils.getVisible(!isConnectedMessage, true));
      guestMessageContentLayout.setVisibility(UIUtils.getVisible(isConnectedMessage, true));

      guestMessageTopView.setBackgroundColor(item.getMessageBackgroundColor());
      guestMessageContentView.setBackgroundColor(item.getMessageBackgroundColor());
      guestMessageText.setBackgroundColor(item.getMessageBackgroundColor());
      guestMessageText.setTextColor(item.getMessageColor());

      guestMessageText.setText(item.getMessage().getFormattedSpanMessage());
      guestMessageText.setMovementMethod(LinkMovementMethod.getInstance());
    }
  }

  private void setManagerMessageText(ChatMessageItem item, boolean isConnectedMessage) {
    if (item.getMessage().getMessage() != null) {
      managerMessageTextLayout.setVisibility(View.VISIBLE);
      managerMessageHeadTop.setVisibility(UIUtils.getVisible(!isConnectedMessage, true));
      managerMessageContextTop.setVisibility(UIUtils.getVisible(isConnectedMessage, true));

      managerMessageText.setText(item.getMessage().getFormattedSpanMessage());
      managerMessageText.setMovementMethod(LinkMovementMethod.getInstance());
    }
  }
}
